@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/port-acl.lisp,v 1.9 2007/04/19 09:10:39 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/port-acl.lisp,v 1.12 2008/04/08 14:39:17 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -49,10 +49,6 @@
 threads can't interfer."
   `(sys:without-scheduling (incf ,place ,delta)))
 
-(defmacro with-timeout ((seconds &body timeout-forms) &body body)
-  "See AllegroCL documentation for SYS:WITH-TIMEOUT."
-  `(sys:with-timeout (,seconds ,@timeout-forms) ,@body))
-
 (defun process-run-function (name function &rest args)
   "See AllegroCL documentation for MP:PROCESS-RUN-FUNCTION."
   (apply #'mp:process-run-function name function args))
@@ -112,9 +108,12 @@ arrived at, and the address and port of the remote host."
                          :read-timeout read-timeout
                          :write-timeout write-timeout)
   (values socket
-          (socket:ipaddr-to-dotted (socket:local-host socket))
-          (socket:ipaddr-to-dotted (socket:remote-host socket))
-          (socket:remote-port socket)))
+          (ignore-errors
+            (socket:ipaddr-to-dotted (socket:local-host socket)))
+          (ignore-errors
+            (socket:ipaddr-to-dotted (socket:remote-host socket)))
+          (ignore-errors
+            (socket:remote-port socket))))
 
 (defun get-backtrace (error)
   "This is the function that is used internally by Hunchentoot to
