@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/port-cmu.lisp,v 1.9 2007/01/01 23:50:30 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/port-cmu.lisp,v 1.12 2008/04/08 14:39:18 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -29,73 +29,106 @@
 
 (in-package :hunchentoot)
 
-#-:mp
-(eval-when (:compile-toplevel :load-toplevel :execute)
-  (error "This library needs a version of CMUCL with MP support."))
-
 (defun make-lock (name)
   "See CMUCL documentation for MP:MAKE-LOCK."
-  (mp:make-lock name))
+  #+:mp
+  (mp:make-lock name)
+  #-:mp
+  name)
 
 (defmacro with-lock ((lock) &body body)
   "See CMUCL documentation for MP:WITH-LOCK-HELD."
-  `(mp:with-lock-held (,lock) ,@body))
+  #+:mp
+  `(mp:with-lock-held (,lock) ,@body)
+  #-:mp
+  (declare (ignore lock))
+  #-:mp
+  `(progn ,@body))
 
 (defmacro atomic-incf (place &optional (delta 1))
   "Like INCF but wrapped with MP:WITHOUT-SCHEDULING so other
 threads can't interfer."
-  `(mp:without-scheduling (incf ,place ,delta)))
-
-(defmacro with-timeout ((seconds &body timeout-forms) &body body)
-  "See CMUCL documentation for MP:WITH-TIMEOUT."
-  `(mp:with-timeout (,seconds ,@timeout-forms) ,@body))
+  `(#+:mp mp:without-scheduling #-:mp progn (incf ,place ,delta)))
 
+#+:mp
 (defun process-run-function (name function &rest args)
   "See CMUCL documentation for MP:MAKE-PROCESS."
   (mp:make-process (lambda ()
                      (apply function args))
                    :name name))
 
+#-:mp
+(defun process-run-function (name function &rest args)
+  "Apply FUNCTION to ARGS - MP compatibility function"
+  (declare (ignore name))
+  (apply function args))
+
 (defun process-kill (process)
   "See CMUCL documentation for MP:DESTROY-PROCESS."
-  (mp:destroy-process process))
+  #+:mp
+  (mp:destroy-process process)
+  #-:mp
+  (declare (ignore process)))
 
+#+:mp
 (define-symbol-macro *current-process*
-  mp:*current-process*)
+    mp:*current-process*)
+
+#-:mp
+(defvar *current-process* "*CURRENT-PROCESS*"
+  "Dummy stub variable for MP-less CMUCL.")
 
 (defun process-allow-scheduling ()
   "See CMUCL documentation for MP:PROCESS-YIELD."
+  #+:mp
   (mp:process-yield))
 
-(defun start-up-server (&key service address process-name announce function &allow-other-keys)
+(defun %run-server (&key service address announce startup-done function &allow-other-keys)
+  "Starts a TCP/IP server listening on the port SERVICE and calling
+FUNCTION with the file descriptor for each incoming connection.  If
+ADDRESS is not NIL, the server only receives connections for this
+address.  Calls ANNOUNCE with the newly created socket, then calls
+STARTUP-DONE with that socket if STARTUP-DONE is not NIL."
+  (let (socket)
+    (unwind-protect
+         (progn
+           (setq socket (ext:create-inet-listener service :stream
+                                                  :reuse-address t
+                                                  :backlog 5
+                                                  :host (or address 0)))
+           (funcall announce socket)
+           (when startup-done
+             (funcall startup-done socket))
+           (loop (funcall function (ext:accept-tcp-connection socket))))
+      (when socket
+        (cl:ignore-errors
+          (ext:close-socket socket))))))
+
+#+:mp
+(defun start-up-server (&rest args &key process-name announce &allow-other-keys)
   "Tries to \(partly) emulate LispWorks' COMM:START-UP-SERVER.  See
 <http://www.lispworks.com/documentation/lw50/LWRM/html/lwref-56.htm>
 for more info."
   (let (done)
-    (flet ((open-socket-and-accept ()
-             (handler-bind ((error (lambda (condition)
-                                     (funcall announce nil condition)
-                                     (setq done condition)
-                                     (return-from open-socket-and-accept))))
-               (let (socket)
-                 (unwind-protect
-                     (progn
-                       (setf socket (ext:create-inet-listener service :stream
-                                                              :reuse-address t
-                                                              :backlog 5
-                                                              :host (or address 0)))
-                       (funcall announce socket)
-                       (setq done socket)
-                       (loop (funcall function (ext:accept-tcp-connection socket))))
-                   (when socket
-                     (cl:ignore-errors
-                       (ext:close-socket socket))))))))
+    (labels ((startup-done (socket)
+               (setf done socket))
+             (open-socket-and-accept ()
+               (handler-bind ((error (lambda (condition)
+                                       (funcall announce nil condition)
+                                       (setq done condition)
+                                       (return-from open-socket-and-accept))))
+                 (apply '%run-server :startup-done #'startup-done args))))
       (let ((listener-thread (process-run-function process-name #'open-socket-and-accept)))
         (mp:process-wait "Waiting for server to start" (lambda () done))
         (typecase done
           (condition (values nil done))
           (t listener-thread))))))
 
+#-:mp
+(defun start-up-server (&rest args &key &allow-other-keys)
+  "Replacement for START-UP-SERVER for MP-less CMUCL."
+  (apply '%run-server args))
+
 (defun format-address (address)
   "Converts an integer in network byte order denoting an IP
 address into the corresponding string representation."
@@ -116,7 +149,7 @@ arrived at, and the address and port of the remote host."
         (ext:get-peer-host-and-port handle)
       (values (sys:make-fd-stream handle
                                   :input t :output t
-                                  :element-type '(unsigned-byte 8)
+                                  :element-type 'octet
                                   :auto-close t
                                   :buffering :full
                                   :timeout read-timeout
