@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/port-lw.lisp,v 1.9 2007/03/09 10:50:24 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/port-lw.lisp,v 1.14 2008/04/08 14:39:18 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -54,39 +54,6 @@
 threads can't interfer."
   `(mp:without-preemption (incf ,place ,delta)))
 
-(defun invoke-with-timeout (duration body-fn timeout-fn)
-  "Executes the function \(with no arguments) BODY-FN and returns
-its results but stops execution after DURATION seconds and then
-instead calls TIMEOUT-FN and returns its values."
-  ;; from Portable AllegroServe
-  (block timeout
-    (let* ((process mp:*current-process*)
-           (unsheduledp nil)
-           (timer (mp:make-timer
-                   #'(lambda ()
-                       (mp:process-interrupt process
-                                             #'(lambda ()
-                                                 (unless unsheduledp
-                                                   (return-from timeout
-                                                     (funcall timeout-fn)))))))))
-      (mp:schedule-timer-relative timer duration)
-      (unwind-protect
-          (funcall body-fn)
-        (mp:without-interrupts
-         (mp:unschedule-timer timer)
-         (setf unsheduledp t))))))
-
-(defmacro with-timeout ((seconds &body timeout-forms) &body body)
-  "Executes the code BODY and returns the results of the last
-form but stops execution after SECONDS seconds and then instead
-executes the code in TIMEOUT-FORMS."
-  ;; from Portable AllegroServe
-  `(invoke-with-timeout ,seconds
-                        #'(lambda ()
-                            ,@body)
-                        #'(lambda ()
-                            ,@timeout-forms)))
-
 (defun process-run-function (name function &rest args)
   "See LispWorks documentation for MP:PROCESS-RUN-FUNCTION."
   (apply #'mp:process-run-function name nil function args))
@@ -111,7 +78,7 @@ executes the code in TIMEOUT-FORMS."
 corresponding stream, setting its read and write timeout if
 applicable.  Returns three other values - the address the request
 arrived at, and the address and port of the remote host."
-  #-:lispworks5.0 (declare (ignore write-timeout))
+  #-:lispworks5 (declare (ignore write-timeout))
   (let ((local-host (comm:get-socket-address socket)))
     (multiple-value-bind (remote-host remote-port)
         (comm:get-socket-peer-address socket)
@@ -119,11 +86,13 @@ arrived at, and the address and port of the remote host."
                  :socket socket
                  :direction :io
                  :read-timeout read-timeout
-                 #+:lispworks5.0 #+:lispworks5.0
+                 #+:lispworks5 #+:lispworks5
                  :write-timeout write-timeout
-                 :element-type '(unsigned-byte 8))
-              (comm:ip-address-string local-host)
-              (comm:ip-address-string remote-host)
+                 :element-type 'octet)
+              (ignore-errors
+                (comm:ip-address-string local-host))
+              (ignore-errors
+                (comm:ip-address-string remote-host))
               remote-port))))
 
 #-:hunchentoot-no-ssl
