@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/port-mcl.lisp,v 1.8 2007/01/01 23:50:30 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/port-mcl.lisp,v 1.11 2008/04/08 14:39:18 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -41,28 +41,6 @@
   "Like INCF, but other threads can't interfer."
   `(ccl::atomic-incf-decf ,place ,delta))
 
-(defun invoke-with-timeout (seconds bodyfn timeoutfn)
-  "Executes the function \(with no arguments) BODY-FN and returns
-its results but stops execution after DURATION seconds and then
-instead calls TIMEOUT-FN and returns its values."
-  ;; from Portable AllegroServe
-  (block timeout
-    (let* ((timer (ccl::make-timer-request seconds
-                                           #'(lambda ()
-                                               (return-from timeout (funcall timeoutfn))))))
-      (ccl::enqueue-timer-request timer)
-      (unwind-protect (funcall bodyfn)
-	(ccl::dequeue-timer-request timer)))))
-
-(defmacro with-timeout ((seconds &body timeout-forms) &body body)
-  "Executes the code BODY and returns the results of the last
-form but stops execution after SECONDS seconds and then instead
-executes the code in TIMEOUT-FORMS."
-  ;; from Portable AllegroServe
-  `(invoke-with-timeout ,seconds
-                        #'(lambda () ,@body)
-                        #'(lambda () ,@timeout-forms)))
-
 (defun process-run-function (name function &rest args)
   "See OpenMCL documentation for CCL:PROCESS-RUN-FUNCTION."
   (apply #'ccl:process-run-function name function args))
@@ -115,11 +93,15 @@ for more info."
 corresponding stream, setting its read and write timeout if
 applicable.  Returns three other values - the address the request
 arrived at, and the address and port of the remote host."
-  (declare (ignore read-timeout write-timeout))
+  (setf (ccl:stream-input-timeout socket) read-timeout)
+  (setf (ccl:stream-output-timeout socket) write-timeout)
   (values socket
-          (ccl:ipaddr-to-dotted (ccl:local-host socket))
-          (ccl:ipaddr-to-dotted (ccl:remote-host socket))
-          (ccl:remote-port socket)))
+          (ignore-errors 
+            (ccl:ipaddr-to-dotted (ccl:local-host socket)))
+          (ignore-errors 
+            (ccl:ipaddr-to-dotted (ccl:remote-host socket)))
+          (ignore-errors
+            (ccl:remote-port socket))))
 
 (defun get-backtrace (error)
   "This is the function that is used internally by Hunchentoot to
