@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/server.lisp,v 1.37 2007/09/06 23:32:10 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/server.lisp,v 1.43 2008/04/09 08:17:48 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -191,14 +191,14 @@ associated with a password."
                                  :dispatch-table dispatch-table
                                  :output-chunking-p (and output-chunking-p (not mod-lisp-p))
                                  :input-chunking-p input-chunking-p
-                                 #-:hunchentoot-no-ssl #-:hunchentoot-no-ssl
-                                 :ssl-certificate-file (and ssl-certificate-file
-                                                            (namestring ssl-certificate-file))
-                                 #-:hunchentoot-no-ssl #-:hunchentoot-no-ssl
-                                 :ssl-privatekey-file (and ssl-privatekey-file
-                                                           (namestring ssl-privatekey-file))
-                                 #-:hunchentoot-no-ssl #-:hunchentoot-no-ssl
-                                 :ssl-privatekey-password ssl-privatekey-password
+                                 #-:hunchentoot-no-ssl :ssl-certificate-file
+                                 #-:hunchentoot-no-ssl(and ssl-certificate-file
+                                                           (namestring ssl-certificate-file))
+                                 #-:hunchentoot-no-ssl :ssl-privatekey-file
+                                 #-:hunchentoot-no-ssl (and ssl-privatekey-file
+                                                            (namestring ssl-privatekey-file))
+                                 #-:hunchentoot-no-ssl :ssl-privatekey-password
+                                 #-:hunchentoot-no-ssl ssl-privatekey-password
                                  :mod-lisp-p mod-lisp-p
                                  :use-apache-log-p (and mod-lisp-p use-apache-log-p)
                                  :read-timeout read-timeout
@@ -308,9 +308,9 @@ closed or until a read timeout occurs."
                                         :privatekey-password (server-ssl-privatekey-password server))
                 #-:lispworks
                 (setq *hunchentoot-stream*
-                        (cl+ssl:make-ssl-server-stream *hunchentoot-stream*
-                                                       :certificate (server-ssl-certificate-file server)
-                                                       :key (server-ssl-privatekey-file server))))
+                      (cl+ssl:make-ssl-server-stream *hunchentoot-stream*
+                                                     :certificate (server-ssl-certificate-file server)
+                                                     :key (server-ssl-privatekey-file server))))
               ;; wrap with chunking-enabled stream if necessary
               (when (or (server-input-chunking-p server)
                         (server-output-chunking-p server))
@@ -342,12 +342,12 @@ closed or until a read timeout occurs."
                                                (flexi-stream-stream *hunchentoot-stream*)) nil
                                               (chunked-stream-input-chunking-p
                                                (flexi-stream-stream *hunchentoot-stream*)) nil))
-                                      (force-output* *hunchentoot-stream*))
+                                      (force-output *hunchentoot-stream*))
                                     ;; continue until we have to close
                                     ;; the stream
                                     (not *close-hunchentoot-stream*))
                          (return)))))
-                (ignore-errors (force-output* *hunchentoot-stream*))))
+                (ignore-errors (force-output *hunchentoot-stream*))))
           (when *hunchentoot-stream*
             (ignore-errors (close *hunchentoot-stream* :abort t)))
           (ignore-errors
@@ -420,7 +420,7 @@ using START-OUTPUT.  If all goes as planned, the function returns T."
                                                    backtrace)))))
                     (with-debugger 
                       ;; skip dispatch if bad request
-                      (when (eq (return-code) +http-ok+)
+                      (when (eql (return-code) +http-ok+)
                         ;; now do the work
                         (dispatch-request *dispatch-table*)))))
               (when error
