@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/test/test.lisp,v 1.20 2007/09/18 14:24:01 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/test/test.lisp,v 1.24 2008/03/06 07:46:53 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -95,9 +95,9 @@
   (load-time-value
    (with-open-file (in (make-pathname :name "fz" :type "jpg" :version nil
                                       :defaults *this-file*)
-                       :element-type '(unsigned-byte 8))
+                       :element-type 'flex:octet)
      (let ((image-data (make-array (file-length in)
-                                   :element-type '(unsigned-byte 8))))
+                                   :element-type 'flex:octet)))
        (read-sequence image-data in)
        image-data))))
 
@@ -219,7 +219,7 @@ time or try with cookies disabled.")
 (defun parameter-test (&key (method :get) (charset :iso-8859-1))
   (no-cache)
   (recompute-request-parameters :external-format
-                                (flexi-streams:make-external-format charset :eol-style :lf))
+                                (flex:make-external-format charset :eol-style :lf))
   (setf (content-type)
         (format nil "text/html; charset=~A" charset))
   (with-html
@@ -360,9 +360,11 @@ and see what's happening.")
 (defun stream-direct ()
   (setf (content-type) "text/html; charset=utf-8")
   (let ((stream (send-headers))
-        (buffer (make-array 1024 :element-type '(unsigned-byte 8))))
+        (buffer (make-array 1024 :element-type 'flex:octet)))
+    #+:clisp
+    (setf (flex:flexi-stream-element-type stream) 'flex:octet)
     (with-open-file (in *utf-8-file*
-                        :element-type '(unsigned-byte 8))
+                        :element-type 'flex:octet)
       (loop for pos = (read-sequence buffer in)
             until (zerop pos) 
             do (write-sequence buffer stream :end pos)))))
@@ -372,7 +374,7 @@ and see what's happening.")
   (let ((stream (send-headers)))
     (setf (flex:flexi-stream-external-format stream) *utf-8*)
     (with-open-file (in (merge-pathnames "UTF-8-demo.html" *this-file*)
-                        :element-type '(unsigned-byte 8))
+                        :element-type 'flex:octet)
       (setq in (flex:make-flexi-stream in :external-format *utf-8*))
       (loop for line = (read-line in nil nil)
             while line
@@ -382,7 +384,7 @@ and see what's happening.")
   (setf (content-type) "text/html; charset=utf-8"
         (reply-external-format) *utf-8*)
   (with-open-file (in (merge-pathnames "UTF-8-demo.html" *this-file*)
-                      :element-type '(unsigned-byte 8))
+                      :element-type 'flex:octet)
     (let ((string (make-array (file-length in)
                               :element-type #-:lispworks 'character #+:lispworks 'lw:simple-char
                               :fill-pointer t)))
