@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/util.lisp,v 1.31 2007/06/04 19:20:22 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/util.lisp,v 1.35 2008/04/08 14:39:18 edi Exp $
 
-;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2004-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -100,31 +100,6 @@ are discarded \(that is, the body is an implicit PROGN)."
                             `(let (,,@temps)
                               ,,@body))))))
 
-(defgeneric maybe-invoke-debugger (condition)
-  (:documentation "This generic function is called whenever a
-condition CONDITION is signaled in Hunchentoot.  You might want to
-specialize it on specific condition classes for debugging purposes.")
-  (:method (condition)
-   "The default method invokes the debugger with CONDITION if
-*CATCH-ERRORS-P* is NIL."
-   (unless *catch-errors-p*
-     (invoke-debugger condition))))
-
-(defmacro with-debugger (&body body)
-  "Executes BODY and invokes the debugger if an error is signaled and
-*CATCH-ERRORS-P* is NIL."
-  `(handler-bind ((error #'maybe-invoke-debugger))
-     ,@body))
-
-(defmacro ignore-errors (&body body)
-  "Like CL:IGNORE-ERRORS, but observes *CATCH-ERRORS-P*."
-  `(cl:ignore-errors (with-debugger ,@body)))
-       
-(defmacro handler-case (expression &rest clauses)
-  "Like CL:HANDLER-CASE, but observes *CATCH-ERRORS-P*."
-  `(cl:handler-case (with-debugger ,expression)
-     ,@clauses))
-
 (defun starts-with-p (seq subseq &key (test 'eql))
   "Tests whether the sequence SEQ starts with the sequence
 SUBSEQ.  Individual elements are compared with TEST."
@@ -279,7 +254,7 @@ called from the RFC2388 library when a file is uploaded."
   "Decodes a URL-encoded STRING which is assumed to be encoded using
 the external format EXTERNAL-FORMAT."
   (let ((vector (make-array (length string)
-                            :element-type '(unsigned-byte 8)
+                            :element-type 'octet
                             :fill-pointer 0)))
     (loop with percent-p and buff
           for char of-type character across string
@@ -330,14 +305,6 @@ alist.  Both names and values are url-decoded while doing this."
                                                                :external-format external-format)
                             do (format s "%~2,'0x" octet)))))))
 
-(defun force-output* (stream)
-  "Like FORCE-OUTPUT but aborts execution after
-*FORCE-OUTPUT-TIMEOUT* seconds."
-  (with-timeout (*force-output-timeout*
-                 (warn "FORCE-OUTPUT didn't return after ~A seconds."
-                       *force-output-timeout*))
-    (force-output stream)))
-
 (defun parse-content-type (content-type-header &optional want-external-format-p)
   "Reads and parses a `Content-Type' header and returns it as three
 values - the type, the subtype, and an external format corresponding
